@@ -19,36 +19,6 @@ from ..interfaces import SignInOkResult, SignInWrongCredentialsError
 from ..types import EmailTemplateVars, User
 
 
-def create_email_verification_token(
-    user_id: str, user_context: Union[None, Dict[str, Any]] = None
-):
-    from supertokens_python.recipe.emailpassword.asyncio import (
-        create_email_verification_token,
-    )
-
-    return sync(create_email_verification_token(user_id, user_context))
-
-
-def verify_email_using_token(
-    token: str, user_context: Union[None, Dict[str, Any]] = None
-):
-    from supertokens_python.recipe.emailpassword.asyncio import verify_email_using_token
-
-    return sync(verify_email_using_token(token, user_context))
-
-
-def unverify_email(user_id: str, user_context: Union[None, Dict[str, Any]] = None):
-    from supertokens_python.recipe.emailpassword.asyncio import unverify_email
-
-    return sync(unverify_email(user_id, user_context))
-
-
-def is_email_verified(user_id: str, user_context: Union[None, Dict[str, Any]] = None):
-    from supertokens_python.recipe.emailpassword.asyncio import is_email_verified
-
-    return sync(is_email_verified(user_id, user_context))
-
-
 def update_email_or_password(
     user_id: str,
     email: Union[str, None] = None,
@@ -112,16 +82,6 @@ def sign_up(
     return sync(sign_up(email, password, user_context))
 
 
-def revoke_email_verification_token(
-    user_id: str, user_context: Union[None, Dict[str, Any]] = None
-):
-    from supertokens_python.recipe.emailpassword.asyncio import (
-        revoke_email_verification_token,
-    )
-
-    return sync(revoke_email_verification_token(user_id, user_context))
-
-
 def send_email(
     input_: EmailTemplateVars, user_context: Union[None, Dict[str, Any]] = None
 ):
