@@ -14,12 +14,21 @@
 from typing import Any, Dict
 
 from supertokens_python.recipe.openid.interfaces import (
-    APIInterface, APIOptions, OpenIdDiscoveryConfigurationGetResponse)
+    APIInterface,
+    APIOptions,
+    OpenIdDiscoveryConfigurationGetResponse,
+)
 
 
 class APIImplementation(APIInterface):
-    async def open_id_discovery_configuration_get(self, api_options: APIOptions, user_context: Dict[str, Any]) ->\
-            OpenIdDiscoveryConfigurationGetResponse:
-        response = await api_options.recipe_implementation.get_open_id_discovery_configuration(user_context)
+    async def open_id_discovery_configuration_get(
+        self, api_options: APIOptions, user_context: Dict[str, Any]
+    ) -> OpenIdDiscoveryConfigurationGetResponse:
+        response = (
+            await api_options.recipe_implementation.get_open_id_discovery_configuration(
+                user_context
+            )
+        )
         return OpenIdDiscoveryConfigurationGetResponse(
-            response.issuer, response.jwks_uri)
+            response.issuer, response.jwks_uri
+        )
