@@ -483,13 +483,6 @@ otp_body = """
 			text-decoration: underline;
 		}
 
-		@media only screen and (min-width:768px) {
-			.templateContainer {
-				width: 600px !important;
-			}
-
-		}
-
 		@media only screen and (max-width: 480px) {
 
 			body,
@@ -1397,13 +1390,6 @@ magic_link_body = """
 			text-decoration: underline;
 		}
 
-		@media only screen and (min-width:768px) {
-			.templateContainer {
-				width: 600px !important;
-			}
-
-		}
-
 		@media only screen and (max-width: 480px) {
 
 			body,
@@ -2327,13 +2313,6 @@ otp_and_magic_link_body = """
 			text-decoration: underline;
 		}
 
-		@media only screen and (min-width:768px) {
-			.templateContainer {
-				width: 600px !important;
-			}
-
-		}
-
 		@media only screen and (max-width: 480px) {
 
 			body,
