@@ -11,14 +11,23 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+from typing import TYPE_CHECKING, List
+
+if TYPE_CHECKING:
+    from .utils import TokenTransferMethod
+
 SESSION_REFRESH = "/session/refresh"
 SIGNOUT = "/signout"
 ACCESS_TOKEN_COOKIE_KEY = "sAccessToken"
 REFRESH_TOKEN_COOKIE_KEY = "sRefreshToken"
-ID_REFRESH_TOKEN_COOKIE_KEY = "sIdRefreshToken"
 FRONT_TOKEN_HEADER_SET_KEY = "front-token"
 ANTI_CSRF_HEADER_KEY = "anti-csrf"
 RID_HEADER_KEY = "rid"
-ID_REFRESH_TOKEN_HEADER_SET_KEY = "id-refresh-token"
-ID_REFRESH_TOKEN_HEADER_GET_KEY = "id-refresh-token"
+AUTH_MODE_HEADER_KEY = "st-auth-mode"
+AUTHORIZATION_HEADER_KEY = "authorization"
+ACCESS_TOKEN_HEADER_KEY = "st-access-token"
+REFRESH_TOKEN_HEADER_KEY = "st-refresh-token"
 ACCESS_CONTROL_EXPOSE_HEADERS = "Access-Control-Expose-Headers"
+
+available_token_transfer_methods: List[TokenTransferMethod] = ["cookie", "header"]
