@@ -178,7 +178,9 @@ class APIImplementation(APIInterface):
 
         user = signinup_response.user
         session = await create_new_session(
-            api_options.request, user.user_id, user_context=user_context
+            api_options.request,
+            user.user_id,
+            user_context=user_context,
         )
 
         return SignInUpPostOkResult(
