@@ -119,7 +119,10 @@ async def test_reset_password_default_backward_compatibility(
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[thirdpartyemailpassword.init(), session.init()],
+        recipe_list=[
+            thirdpartyemailpassword.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
+        ],
     )
     start_st()
 
@@ -168,7 +171,10 @@ async def test_reset_password_default_backward_compatibility_suppress_error(
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[thirdpartyemailpassword.init(), session.init()],
+        recipe_list=[
+            thirdpartyemailpassword.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
+        ],
     )
     start_st()
 
@@ -229,7 +235,7 @@ async def test_reset_password_backward_compatibility(driver_config_client: TestC
                     create_and_send_custom_email=custom_create_and_send_custom_email,
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -281,7 +287,7 @@ async def test_reset_password_custom_override(driver_config_client: TestClient):
                     override=email_delivery_override,
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -398,7 +404,7 @@ async def test_reset_password_smtp_service(driver_config_client: TestClient):
                     override=email_delivery_override,
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -444,7 +450,7 @@ async def test_reset_password_backward_compatibility_non_existent_user(
                     create_and_send_custom_email=custom_create_and_send_custom_email,
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -481,7 +487,7 @@ async def test_email_verification_default_backward_compatibility(
         recipe_list=[
             emailverification.init(mode="OPTIONAL"),
             thirdpartyemailpassword.init(),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -492,7 +498,7 @@ async def test_email_verification_default_backward_compatibility(
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -511,7 +517,6 @@ async def test_email_verification_default_backward_compatibility(
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -546,7 +551,7 @@ async def test_email_verification_default_backward_compatibility_suppress_error(
         recipe_list=[
             emailverification.init(mode="OPTIONAL"),
             thirdpartyemailpassword.init(),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -557,7 +562,7 @@ async def test_email_verification_default_backward_compatibility_suppress_error(
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -576,7 +581,6 @@ async def test_email_verification_default_backward_compatibility_suppress_error(
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -621,7 +625,7 @@ async def test_email_verification_backward_compatibility(
                 create_and_send_custom_email=custom_create_and_send_custom_email,
             ),
             thirdpartyemailpassword.init(),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -632,12 +636,11 @@ async def test_email_verification_backward_compatibility(
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, False, {}, {})
 
     res = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -691,7 +694,7 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
                 ),
             ),
             thirdpartyemailpassword.init(),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -702,7 +705,7 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -719,7 +722,6 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -822,7 +824,7 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
                 ),
             ),
             thirdpartyemailpassword.init(),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -833,12 +835,11 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     resp = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -886,7 +887,7 @@ async def test_reset_password_backward_compatibility_thirdparty_user(
                     create_and_send_custom_email=custom_create_and_send_custom_email,
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -899,12 +900,11 @@ async def test_reset_password_backward_compatibility_thirdparty_user(
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     res = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -950,7 +950,7 @@ async def test_email_verification_backward_compatibility_thirdparty_user(
                     Github(client_id="", client_secret="")
                 ],  # Note: Provider must be passed to init TP recipe
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -963,12 +963,11 @@ async def test_email_verification_backward_compatibility_thirdparty_user(
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
         raise Exception("Should never come here")
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     res = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
